aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/frotz/processor.h
diff options
context:
space:
mode:
authorPaul Gilbert2018-11-13 20:05:59 -0800
committerPaul Gilbert2018-12-08 19:05:59 -0800
commita2104deb4cefdcf0cd6bb3a66ef09bb46cba3f66 (patch)
tree802a8abed7a2f97aa9fa0d7f467054a9e0ab79b8 /engines/glk/frotz/processor.h
parent1fb931fbd950324754536ee0b33ed0b91f68c9a2 (diff)
downloadscummvm-rg350-a2104deb4cefdcf0cd6bb3a66ef09bb46cba3f66.tar.gz
scummvm-rg350-a2104deb4cefdcf0cd6bb3a66ef09bb46cba3f66.tar.bz2
scummvm-rg350-a2104deb4cefdcf0cd6bb3a66ef09bb46cba3f66.zip
GLK: Changing class and namespaces from Gargoyle to Glk
Diffstat (limited to 'engines/glk/frotz/processor.h')
-rw-r--r--engines/glk/frotz/processor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/glk/frotz/processor.h b/engines/glk/frotz/processor.h
index b5c113def0..4bd9d2c5af 100644
--- a/engines/glk/frotz/processor.h
+++ b/engines/glk/frotz/processor.h
@@ -28,7 +28,7 @@
#include "glk/frotz/frotz_types.h"
#include "common/stack.h"
-namespace Gargoyle {
+namespace Glk {
namespace Frotz {
#define TEXT_BUFFER_SIZE 200
@@ -1522,7 +1522,7 @@ public:
/**
* Constructor
*/
- Processor(OSystem *syst, const GargoyleGameDescription *gameDesc);
+ Processor(OSystem *syst, const GlkGameDescription *gameDesc);
/**
* Initialization
@@ -1579,6 +1579,6 @@ public:
};
} // End of namespace Frotz
-} // End of namespace Gargoyle
+} // End of namespace Glk
#endif